@@ -1027,10 +1027,11 @@ class MetadynamicSimulation(MDSimulation):
     you can use the following:
 
     >>> CV_list = [
-    >>>    ['Coordination Number',[100,110],[200,210],.5,1,.025,[1/2,1/2],[.5,.5]]
+    >>>    ['Coordination Number',[100,110],[200,210],.5,1,.025,[1/2,1/2],[.7,.6], [.289, .354]]
     >>>]
 
-    where cv[6] and cv[7] correspond to the weights and the unbound_distance/2 for the atom pairs in cv[1] and cv[2].
+    where cv[6] and cv[7] correspond to the weights and the unbound_distance/2 for the atom pairs in cv[1] and cv[2],
+    and cv[8] corresponds to the initial distance between the groups of atoms cv[1] and cv[2].
 
     All structures should be aligned such that the Distance CV is aligned along the Z-axis. This can be done using
     ommtk align_structure() command, but should be done before solvating the system as rotating a system after
