@@ -45,7 +45,8 @@ class SegmentMappingSim(MetadynamicSimulation):
                  num_replicas=1, CV2_target_range = None,
                  time_per_iteration =10 * unit.nanosecond,
                  run_scans=True, run_production=True, input_scan_times=None, input_segment_coords=None,
-                 max_iterations=15, coverage_criteria=.28,
+                 max_iterations=15, coverage_criteria=.5, min_coverage_criteria=.25, convergence_criteria=.1,
+                 retain_scan_bias=True,
                  **kwargs):
 
         super().__init__(**kwargs)
@@ -69,7 +70,10 @@ class SegmentMappingSim(MetadynamicSimulation):
         self.input_segment_coords = input_segment_coords
         self.CV2_target_range = CV2_target_range
         self.max_iterations = max_iterations
+        self.retain_scan_bias = retain_scan_bias
         self.coverage_criteria = coverage_criteria
+        self.min_coverage_criteria = min_coverage_criteria
+        self.convergence_criteria = convergence_criteria
 
 
         #sanity checks
@@ -121,8 +125,9 @@ class SegmentMappingSim(MetadynamicSimulation):
             chosen_CVs_all_replicas = []
             for i in range(self.num_replicas):
 
-                self._remove_custom_forces()
-                self._build_custom_forces()
+                if self.retain_scan_bias==False:
+                    self._remove_custom_forces()
+                    self._build_custom_forces()
 
                 print('Starting scan run for replica {}'.format(i+1))
 
@@ -358,7 +363,8 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
         print('nsteps for production phase',nsteps)
         self.simulation.reporters = []
         self._add_reporters(total_steps = nsteps + self.simulation.currentStep)
-        self._add_FESReporter()
+        #once again we fix the FES Reporter freq to ensure convergence detection works
+        self._add_FESReporter(fes_interval=.01 * unit.nanosecond)
 
         self.cycle_replicas(self.segment_coords)
 
@@ -372,18 +378,29 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
 
         #segment coords are a list of frames, each replica
 
-        coverage = 0
         sim_time=0 * unit.nanosecond
         accepted = 0
         attempted = 0
-        while coverage<=self.coverage_criteria and sim_time<=self.max_production_time:
-            #get coverage first so that there's always one more iteration after coverage is reached
+        continue_simulating=True
+        dG_std = 100
+        while continue_simulating:
+
+            #calc coverage, dG_std and detect convergence
             coverage = calc_coverage(self.metaD.getFreeEnergy().value_in_unit(unit.kilocalorie_per_mole))
             print('coverage is currently {:.2f}%'.format(coverage * 100))
-            #loop across all replicas
+            with open(os.path.join(self.cwd,'segment_coords.pickle'),'rb') as handle:
+                dG_trace = pickle.load(handle)
+            #if fes_interval is .01 then 100 is variance across 2 ns
+            if len(dG_trace)>200:
+                dG_std = np.std(dG_trace[len(dG_trace-200):])
+
+            if coverage>self.min_coverage_criteria and dG_std < self.convergence_criteria:
+                print('convergence detected!')
+                continue_simulating= False
+
+            #run the sim
             self.metaD.step(self.simulation, steps_per_swap_attempt)
             sim_time += self.swap_freq
-            print(sim_time)
             #get current coords and energy
             state = self.simulation.context.getState(getEnergy=True,getPositions=True)
             current_positions = state.getPositions()
@@ -398,8 +415,7 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
             proposed_energy = self.simulation.context.getState(getEnergy=True).getPotentialEnergy()
             log_p_accept = proposed_energy-current_energy
             current_cv1_distance = self.metaD.getCollectiveVariables(self.simulation)[0]
-            print('current cv1 distance', current_cv1_distance)
-            print('logp accept, high_temp_accept',log_p_accept,np.exp(-(log_p_accept/2.5).value_in_unit(unit.kilojoule_per_mole)))
+            print('current cv1 distance', current_cv1_distance,'logp accept',log_p_accept)
             #compare deltaU of swap and normalize high energy probability of acceptance by 2.5 (energy of room temp in kJ/mol)
             if log_p_accept<=0 * unit.kilojoules_per_mole \
                     or random.random() < np.exp(-(log_p_accept/2.494341741366065).value_in_unit(unit.kilojoule_per_mole)) \
@@ -413,4 +429,7 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
                 self.simulation.context.setPositions(current_positions)
             print('HREMD acceptance rate {}'.format(accepted/attempted))
 
+            if sim_time>=self.max_production_time:
+                print('hit max sim time')
+                continue_simulating = False
 
