@@ -459,17 +459,21 @@ def align_structure(pmd, sel1, sel2, axis):
 
     return pmd
 
-def calc_dG(fes,well_combining_method):
-    """
-    Input a free energy surface and calculate energy difference between wells. It is agnostic to units
+def calc_coverage(fes):
+    segmented_fes = np.zeros_like(fes)
+    for i,row in enumerate(fes):
+        for k, value in enumerate(row):
+            if value<-.01:
+                segmented_fes[i,k]=1
+    coverage = ( np.count_nonzero(segmented_fes) / float(segmented_fes.size) )
+    return coverage
 
-    :param fes: 2D matrix in format given by FESResporter
-    :param well_combining_method: string ['mean','max']
-    :return: dG estimate (float)
-    """
+def calc_dG(fes,order,cutoff=.75):
+    #use cropped fes to avoid end cliffs
     fes = np.array(fes)
-    minimax = signal.argrelextrema(fes, np.less)
-    minimay = signal.argrelextrema(fes, np.less, axis=1)
+    fes = fes[:,:int(np.shape(fes)[0]*cutoff)]
+    minimax = signal.argrelextrema(fes, np.less, order=order)
+    minimay = signal.argrelextrema(fes, np.less, order=order,axis=1)
 
     y_direction = set()
     for i in range(len(minimay[0])):
@@ -496,12 +500,7 @@ def calc_dG(fes,well_combining_method):
             dG_list.append(dG_val)
 
     if len(dG_list) == 0:
-        print('dG_list empty')
         dG = 0
     else:
-        if well_combining_method=='mean':
             dG = np.mean(dG_list)
-        if well_combining_method=='max':
-            dG = np.max(dG_list)
-
     return dG
